@@ -1,11 +1,13 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 # To suppress messages
 library(tibble)
 library(vctrs)
 
-knitr::opts_chunk$set(error = TRUE)
-
-tibble:::set_fansi_hooks()
+knitr::opts_chunk$set(
+  collapse = TRUE,
+  comment = "#>",
+  error = TRUE
+)
 tibble:::set_dftbl_hooks()
 
 options(
@@ -121,20 +123,20 @@ tbl[[1]]
 .subset2(tbl, 1)
 
 ## ----double-bracket-equivalent-to-subset2-detail, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  identical(df[[3]], .subset2(df, 3))
-#  identical(tbl[[3]], .subset2(tbl, 3))
-#  identical(df2[["df"]], .subset2(df2, "df"))
-#  identical(tbl2[["tbl"]], .subset2(tbl2, "tbl"))
+# identical(df[[3]], .subset2(df, 3))
+# identical(tbl[[3]], .subset2(tbl, 3))
+# identical(df2[["df"]], .subset2(df2, "df"))
+# identical(tbl2[["tbl"]], .subset2(tbl2, "tbl"))
 
 ## ----double-bracket-retains-size, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  vec_size(df[[1]])
-#  vec_size(tbl[[1]])
-#  vec_size(df[[3]])
-#  vec_size(tbl[[3]])
-#  vec_size(df2[[1]])
-#  vec_size(tbl2[[1]])
-#  vec_size(df2[[2]])
-#  vec_size(tbl2[[2]])
+# vec_size(df[[1]])
+# vec_size(tbl[[1]])
+# vec_size(df[[3]])
+# vec_size(tbl[[3]])
+# vec_size(df2[[1]])
+# vec_size(tbl2[[1]])
+# vec_size(df2[[2]])
+# vec_size(tbl2[[2]])
 
 ## ----double-bracket-requires-scalar-j-index, dftbl = TRUE---------------------
 df[[1:2]]
@@ -175,12 +177,12 @@ tbl$"n"
 tbl[["n"]]
 
 ## ----dollar-equivalent-to-subset-detail, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  identical(df$li, df[["li"]])
-#  identical(tbl$li, tbl[["li"]])
-#  identical(df2$tb, df2[["tb"]])
-#  identical(tbl2$tb, tbl2[["tb"]])
-#  identical(df2$m, df2[["m"]])
-#  identical(tbl2$m, tbl2[["m"]])
+# identical(df$li, df[["li"]])
+# identical(tbl$li, tbl[["li"]])
+# identical(df2$tb, df2[["tb"]])
+# identical(tbl2$tb, tbl2[["tb"]])
+# identical(df2$m, df2[["m"]])
+# identical(tbl2$m, tbl2[["m"]])
 
 ## ----dollar-equivalent-to-subset-pmatch, dftbl = TRUE-------------------------
 df$l
@@ -213,22 +215,22 @@ tbl[, 1]
 tbl[, 1:2]
 
 ## ----bracket-missing-i-detail, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  identical(df[, 2:3], df[2:3])
-#  identical(tbl[, 2:3], tbl[2:3])
-#  identical(df2[, 1:2], df2[1:2])
-#  identical(tbl2[, 1:2], tbl2[1:2])
+# identical(df[, 2:3], df[2:3])
+# identical(tbl[, 2:3], tbl[2:3])
+# identical(df2[, 1:2], df2[1:2])
+# identical(tbl2[, 1:2], tbl2[1:2])
 
 ## ----bracket-always-returns-tibble-drop, dftbl = TRUE-------------------------
 
 tbl[, 1, drop = TRUE]
 
 ## ----bracket-always-returns-tibble-drop-detail, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  identical(df[, 3, drop = TRUE], df[[3]])
-#  identical(tbl[, 3, drop = TRUE], tbl[[3]])
-#  identical(df2[, 1, drop = TRUE], df2[[1]])
-#  identical(tbl2[, 1, drop = TRUE], tbl2[[1]])
-#  identical(df2[, 2, drop = TRUE], df2[[2]])
-#  identical(tbl2[, 2, drop = TRUE], tbl2[[2]])
+# identical(df[, 3, drop = TRUE], df[[3]])
+# identical(tbl[, 3, drop = TRUE], tbl[[3]])
+# identical(df2[, 1, drop = TRUE], df2[[1]])
+# identical(tbl2[, 1, drop = TRUE], tbl2[[1]])
+# identical(df2[, 2, drop = TRUE], df2[[2]])
+# identical(tbl2[, 2, drop = TRUE], tbl2[[2]])
 
 ## ----bracket-i, dftbl = TRUE--------------------------------------------------
 
@@ -243,9 +245,9 @@ tbl[list(1), ]
 tbl["1", ]
 
 ## ----bracket-i-oob, dftbl = TRUE----------------------------------------------
-df[10, ]
+
 tbl[10, ]
-df["x", ]
+
 tbl["x", ]
 
 ## ----bracket-i-recycle, dftbl = TRUE------------------------------------------
@@ -263,54 +265,54 @@ df[1, , drop = TRUE]
 tbl[1, , drop = TRUE]
 
 ## ----bracket-i-j-equivalent-to-i-subset-then-j, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  df[1, 1]
-#  tbl[1, 1]
-#  df[1, ][1]
-#  tbl[1, ][1]
-#  identical(df[1, 2:3], df[2:3][1, ])
-#  identical(tbl[1, 2:3], tbl[2:3][1, ])
-#  identical(df[2:3, 1], df[1][2:3, ])
-#  identical(tbl[2:3, 1], tbl[1][2:3, ])
-#  identical(df2[2:3, 1:2], df2[1:2][2:3, ])
-#  identical(tbl2[2:3, 1:2], tbl2[1:2][2:3, ])
+# df[1, 1]
+# tbl[1, 1]
+# df[1, ][1]
+# tbl[1, ][1]
+# identical(df[1, 2:3], df[2:3][1, ])
+# identical(tbl[1, 2:3], tbl[2:3][1, ])
+# identical(df[2:3, 1], df[1][2:3, ])
+# identical(tbl[2:3, 1], tbl[1][2:3, ])
+# identical(df2[2:3, 1:2], df2[1:2][2:3, ])
+# identical(tbl2[2:3, 1:2], tbl2[1:2][2:3, ])
 
 ## ----bracket-bracket-i-j-equivalent-to-i-subset-then-j------------------------
 df[[1, 1]]
 df[[1, 3]]
 
 ## ----double-bracket-assign-definition, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df(df[[1]] <- 0)
-#  with_tbl(tbl[[1]] <- 0)
-#  with_df(df[[3]] <- 4:1)
-#  with_tbl(tbl[[3]] <- 4:1)
-#  with_df2(df2[[1]] <- 0)
-#  with_tbl2(tbl2[[1]] <- 0)
-#  with_df2(df2[[2]] <- 4:1)
-#  with_tbl2(tbl2[[2]] <- 4:1)
+# with_df(df[[1]] <- 0)
+# with_tbl(tbl[[1]] <- 0)
+# with_df(df[[3]] <- 4:1)
+# with_tbl(tbl[[3]] <- 4:1)
+# with_df2(df2[[1]] <- 0)
+# with_tbl2(tbl2[[1]] <- 0)
+# with_df2(df2[[2]] <- 4:1)
+# with_tbl2(tbl2[[2]] <- 4:1)
 
 ## ----double-bracket-assign-requires-scalar-j-index, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df(df[[1]] <- 0)
-#  with_tbl(tbl[[1]] <- 0)
-#  with_df(df[["c"]] <- 0)
-#  with_tbl(tbl[["c"]] <- 0)
+# with_df(df[[1]] <- 0)
+# with_tbl(tbl[[1]] <- 0)
+# with_df(df[["c"]] <- 0)
+# with_tbl(tbl[["c"]] <- 0)
 
 ## ----double-bracket-assign-requires-scalar-j-index-error, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df(df[[TRUE]] <- 0)
-#  with_tbl(tbl[[TRUE]] <- 0)
-#  with_df(df[[1:3]] <- 0)
-#  with_tbl(tbl[[1:3]] <- 0)
-#  with_df(df[[c("n", "c")]] <- 0)
-#  with_tbl(tbl[[c("n", "c")]] <- 0)
-#  with_df(df[[FALSE]] <- 0)
-#  with_tbl(tbl[[FALSE]] <- 0)
-#  with_df(df[[1:2]] <- 0)
-#  with_tbl(tbl[[1:2]] <- 0)
-#  with_df(df[[NA_integer_]] <- 0)
-#  with_tbl(tbl[[NA_integer_]] <- 0)
-#  with_df(df[[NA]] <- 0)
-#  with_tbl(tbl[[NA]] <- 0)
-#  with_df(df[[NA_character_]] <- 0)
-#  with_tbl(tbl[[NA_character_]] <- 0)
+# with_df(df[[TRUE]] <- 0)
+# with_tbl(tbl[[TRUE]] <- 0)
+# with_df(df[[1:3]] <- 0)
+# with_tbl(tbl[[1:3]] <- 0)
+# with_df(df[[c("n", "c")]] <- 0)
+# with_tbl(tbl[[c("n", "c")]] <- 0)
+# with_df(df[[FALSE]] <- 0)
+# with_tbl(tbl[[FALSE]] <- 0)
+# with_df(df[[1:2]] <- 0)
+# with_tbl(tbl[[1:2]] <- 0)
+# with_df(df[[NA_integer_]] <- 0)
+# with_tbl(tbl[[NA_integer_]] <- 0)
+# with_df(df[[NA]] <- 0)
+# with_tbl(tbl[[NA]] <- 0)
+# with_df(df[[NA_character_]] <- 0)
+# with_tbl(tbl[[NA_character_]] <- 0)
 
 ## ----double-bracket-assign-recycle, dftbl = TRUE------------------------------
 
@@ -321,14 +323,14 @@ with_df2(df2[["m"]] <- df2[["m"]][1, , drop = FALSE])
 with_tbl2(tbl2[["m"]] <- tbl2[["m"]][1, , drop = FALSE])
 
 ## ----double-bracket-requires-size, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df(df[[1]] <- 1)
-#  with_tbl(tbl[[1]] <- 1)
-#  with_df(df[[1]] <- 4:1)
-#  with_tbl(tbl[[1]] <- 4:1)
-#  with_df(df[[1]] <- 3:1)
-#  with_tbl(tbl[[1]] <- 3:1)
-#  with_df(df[[1]] <- 2:1)
-#  with_tbl(tbl[[1]] <- 2:1)
+# with_df(df[[1]] <- 1)
+# with_tbl(tbl[[1]] <- 1)
+# with_df(df[[1]] <- 4:1)
+# with_tbl(tbl[[1]] <- 4:1)
+# with_df(df[[1]] <- 3:1)
+# with_tbl(tbl[[1]] <- 3:1)
+# with_df(df[[1]] <- 2:1)
+# with_tbl(tbl[[1]] <- 2:1)
 
 ## ----double-bracket-assign-supports-new, dftbl = TRUE-------------------------
 
@@ -339,26 +341,26 @@ with_df(df[[5]] <- 0)
 with_tbl(tbl[[5]] <- 0)
 
 ## ----double-bracket-assign-supports-type-change, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df(df[[1]] <- df[[2]])
-#  with_tbl(tbl[[1]] <- tbl[[2]])
-#  with_df(df[[2]] <- df[[3]])
-#  with_tbl(tbl[[2]] <- tbl[[3]])
-#  with_df(df[[3]] <- df2[[1]])
-#  with_tbl(tbl[[3]] <- tbl2[[1]])
-#  with_df2(df2[[1]] <- df2[[2]])
-#  with_tbl2(tbl2[[1]] <- tbl2[[2]])
-#  with_df2(df2[[2]] <- df[[1]])
-#  with_tbl2(tbl2[[2]] <- tbl[[1]])
+# with_df(df[[1]] <- df[[2]])
+# with_tbl(tbl[[1]] <- tbl[[2]])
+# with_df(df[[2]] <- df[[3]])
+# with_tbl(tbl[[2]] <- tbl[[3]])
+# with_df(df[[3]] <- df2[[1]])
+# with_tbl(tbl[[3]] <- tbl2[[1]])
+# with_df2(df2[[1]] <- df2[[2]])
+# with_tbl2(tbl2[[1]] <- tbl2[[2]])
+# with_df2(df2[[2]] <- df[[1]])
+# with_tbl2(tbl2[[2]] <- tbl[[1]])
 
 ## ----double-bracket-assign-supports-null, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df(df[[1]] <- NULL)
-#  with_tbl(tbl[[1]] <- NULL)
-#  with_df2(df2[[2]] <- NULL)
-#  with_tbl2(tbl2[[2]] <- NULL)
+# with_df(df[[1]] <- NULL)
+# with_tbl(tbl[[1]] <- NULL)
+# with_df2(df2[[2]] <- NULL)
+# with_tbl2(tbl2[[2]] <- NULL)
 
 ## ----double-bracket-assign-supports-null-unknown, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df(df[["q"]] <- NULL)
-#  with_tbl(tbl[["q"]] <- NULL)
+# with_df(df[["q"]] <- NULL)
+# with_tbl(tbl[["q"]] <- NULL)
 
 ## ----dollar-equivalent-to-subset-assign, dftbl = TRUE-------------------------
 
@@ -367,8 +369,8 @@ with_tbl(tbl$n <- 0)
 with_tbl(tbl[["n"]] <- 0)
 
 ## ----dollar-equivalent-to-subset-assign-detail, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df(df$"n" <- 0)
-#  with_tbl(tbl$"n" <- 0)
+# with_df(df$"n" <- 0)
+# with_tbl(tbl$"n" <- 0)
 
 ## ----dollar-equivalent-to-subset-assign-pmatch, dftbl = TRUE------------------
 
@@ -390,7 +392,7 @@ with_tbl(tbl[1:2] <- list(0, 0, 0))
 with_df(df[1:3] <- list(0, 0))
 with_tbl(tbl[1:3] <- list(0, 0))
 
-## ---- bracket-assign-multiple, dftbl = TRUE-----------------------------------
+## ----bracket-assign-multiple, dftbl = TRUE------------------------------------
 with_df(df[c(1, 1)] <- list(1, 2))
 with_tbl(tbl[c(1, 1)] <- list(1, 2))
 
@@ -399,24 +401,24 @@ with_tbl(tbl[c(1, 1)] <- list(1, 2))
 with_tbl(tbl[1:2] <- list(NULL, 4:1))
 
 ## ----bracket-assign-na, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df(df[NA] <- list("x"))
-#  with_tbl(tbl[NA] <- list("x"))
-#  with_df(df[NA_integer_] <- list("x"))
-#  with_tbl(tbl[NA_integer_] <- list("x"))
-#  with_df(df[NA_character_] <- list("x"))
-#  with_tbl(tbl[NA_character_] <- list("x"))
+# with_df(df[NA] <- list("x"))
+# with_tbl(tbl[NA] <- list("x"))
+# with_df(df[NA_integer_] <- list("x"))
+# with_tbl(tbl[NA_integer_] <- list("x"))
+# with_df(df[NA_character_] <- list("x"))
+# with_tbl(tbl[NA_character_] <- list("x"))
 
 ## ----bracket-assign-supports-type-change, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df(df[1] <- df[2])
-#  with_tbl(tbl[1] <- tbl[2])
-#  with_df(df[2] <- df[3])
-#  with_tbl(tbl[2] <- tbl[3])
-#  with_df(df[3] <- df2[1])
-#  with_tbl(tbl[3] <- tbl2[1])
-#  with_df2(df2[1] <- df2[2])
-#  with_tbl2(tbl2[1] <- tbl2[2])
-#  with_df2(df2[2] <- df[1])
-#  with_tbl2(tbl2[2] <- tbl[1])
+# with_df(df[1] <- df[2])
+# with_tbl(tbl[1] <- tbl[2])
+# with_df(df[2] <- df[3])
+# with_tbl(tbl[2] <- tbl[3])
+# with_df(df[3] <- df2[1])
+# with_tbl(tbl[3] <- tbl2[1])
+# with_df2(df2[1] <- df2[2])
+# with_tbl2(tbl2[1] <- tbl2[2])
+# with_df2(df2[2] <- df[1])
+# with_tbl2(tbl2[2] <- tbl[1])
 
 ## ----bracket-assign-names, dftbl = TRUE---------------------------------------
 
@@ -485,24 +487,24 @@ with_tbl(tbl[2:3, ] <- tbl[1, ])
 with_tbl(tbl[c(FALSE, TRUE, TRUE, FALSE), ] <- tbl[1, ])
 
 ## ----bracket-i-assign-detail, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df(df[0:2, ] <- df[1, ])
-#  with_tbl(tbl[0:2, ] <- tbl[1, ])
-#  with_df(df[0, ] <- df[1, ])
-#  with_tbl(tbl[0, ] <- tbl[1, ])
-#  with_df(df[-2, ] <- df[1, ])
-#  with_tbl(tbl[-2, ] <- tbl[1, ])
-#  with_df(df[-1:2, ] <- df[1, ])
-#  with_tbl(tbl[-1:2, ] <- tbl[1, ])
-#  with_df(df[NA_integer_, ] <- df[1, ])
-#  with_tbl(tbl[NA_integer_, ] <- tbl[1, ])
-#  with_df2(df2[NA_integer_, ] <- df2[1, ])
-#  with_tbl2(tbl2[NA_integer_, ] <- tbl2[1, ])
-#  with_df(df[TRUE, ] <- df[1, ])
-#  with_tbl(tbl[TRUE, ] <- tbl[1, ])
-#  with_df(df[FALSE, ] <- df[1, ])
-#  with_tbl(tbl[FALSE, ] <- tbl[1, ])
-#  with_df(df[NA, ] <- df[1, ])
-#  with_tbl(tbl[NA, ] <- tbl[1, ])
+# with_df(df[0:2, ] <- df[1, ])
+# with_tbl(tbl[0:2, ] <- tbl[1, ])
+# with_df(df[0, ] <- df[1, ])
+# with_tbl(tbl[0, ] <- tbl[1, ])
+# with_df(df[-2, ] <- df[1, ])
+# with_tbl(tbl[-2, ] <- tbl[1, ])
+# with_df(df[-1:2, ] <- df[1, ])
+# with_tbl(tbl[-1:2, ] <- tbl[1, ])
+# with_df(df[NA_integer_, ] <- df[1, ])
+# with_tbl(tbl[NA_integer_, ] <- tbl[1, ])
+# with_df2(df2[NA_integer_, ] <- df2[1, ])
+# with_tbl2(tbl2[NA_integer_, ] <- tbl2[1, ])
+# with_df(df[TRUE, ] <- df[1, ])
+# with_tbl(tbl[TRUE, ] <- tbl[1, ])
+# with_df(df[FALSE, ] <- df[1, ])
+# with_tbl(tbl[FALSE, ] <- tbl[1, ])
+# with_df(df[NA, ] <- df[1, ])
+# with_tbl(tbl[NA, ] <- tbl[1, ])
 
 ## ----bracket-i-recycle-assign, dftbl = TRUE-----------------------------------
 
@@ -513,10 +515,10 @@ with_df(df[2:4, ] <- df[1:2, ])
 with_tbl(tbl[2:4, ] <- tbl[1:2, ])
 
 ## ----bracket-i-recycle-assign-detail, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df2(df2[2:4, ] <- df2[1, ])
-#  with_tbl2(tbl2[2:4, ] <- tbl2[1, ])
-#  with_df2(df2[2:4, ] <- df2[2:3, ])
-#  with_tbl2(tbl2[2:4, ] <- tbl2[2:3, ])
+# with_df2(df2[2:4, ] <- df2[1, ])
+# with_tbl2(tbl2[2:4, ] <- tbl2[1, ])
+# with_df2(df2[2:4, ] <- df2[2:3, ])
+# with_tbl2(tbl2[2:4, ] <- tbl2[2:3, ])
 
 ## ----bracket-i-oob-num, dftbl = TRUE------------------------------------------
 
@@ -537,14 +539,14 @@ with_tbl(tbl[-6, ] <- tbl[1, ])
 with_tbl(tbl[as.character(1:3), ] <- tbl[1, ])
 
 ## ----bracket-i-character-detail, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df(df[as.character(-(1:3)), ] <- df[1, ])
-#  with_tbl(tbl[as.character(-(1:3)), ] <- tbl[1, ])
-#  with_df(df[as.character(3:5), ] <- df[1, ])
-#  with_tbl(tbl[as.character(3:5), ] <- tbl[1, ])
-#  with_df(df[as.character(-(3:5)), ] <- df[1, ])
-#  with_tbl(tbl[as.character(-(3:5)), ] <- tbl[1, ])
-#  with_df(df[NA_character_, ] <- df[1, ])
-#  with_tbl(tbl[NA_character_, ] <- tbl[1, ])
+# with_df(df[as.character(-(1:3)), ] <- df[1, ])
+# with_tbl(tbl[as.character(-(1:3)), ] <- tbl[1, ])
+# with_df(df[as.character(3:5), ] <- df[1, ])
+# with_tbl(tbl[as.character(3:5), ] <- tbl[1, ])
+# with_df(df[as.character(-(3:5)), ] <- df[1, ])
+# with_tbl(tbl[as.character(-(3:5)), ] <- tbl[1, ])
+# with_df(df[NA_character_, ] <- df[1, ])
+# with_tbl(tbl[NA_character_, ] <- tbl[1, ])
 
 ## ----bracket-i-data-type, dftbl = TRUE----------------------------------------
 with_df(df[2:3, 1] <- df[1:2, 2])
@@ -581,26 +583,26 @@ with_tbl(tbl[2:3, "n"] <- NULL)
 with_tbl(tbl[5, "n"] <- list(0L))
 
 ## ----double-bracket-i-j-equivalent-to-row-subset-then-j, dftbl = TRUE, include = eval_details, eval = eval_details----
-#  with_df(df[[1, 1]] <- 0)
-#  with_tbl(tbl[[1, 1]] <- 0)
-#  with_df(df[1, ][[1]] <- 0)
-#  with_tbl(tbl[1, ][[1]] <- 0)
-#  with_df(df[[1, 3]] <- list(NULL))
-#  with_tbl(tbl[[1, 3]] <- list(NULL))
-#  with_df(df[1, ][[3]] <- list(NULL))
-#  with_tbl(tbl[1, ][[3]] <- list(NULL))
-#  with_df2(df2[[1, 1]] <- df[1, ])
-#  with_tbl2(tbl2[[1, 1]] <- tbl[1, ])
-#  with_df2(df2[1, ][[1]] <- df[1, ])
-#  with_tbl2(tbl2[1, ][[1]] <- tbl[1, ])
-#  with_df2(df2[[1, 2]] <- t(1:4))
-#  with_tbl2(tbl2[[1, 2]] <- t(1:4))
-#  with_df2(df2[1, ][[2]] <- t(1:4))
-#  with_tbl2(tbl2[1, ][[2]] <- t(1:4))
-#  df[[1:2, 1]]
-#  tbl[[1:2, 1]]
-#  with_df(df[[1:2, 1]] <- 0)
-#  with_tbl(tbl[[1:2, 1]] <- 0)
+# with_df(df[[1, 1]] <- 0)
+# with_tbl(tbl[[1, 1]] <- 0)
+# with_df(df[1, ][[1]] <- 0)
+# with_tbl(tbl[1, ][[1]] <- 0)
+# with_df(df[[1, 3]] <- list(NULL))
+# with_tbl(tbl[[1, 3]] <- list(NULL))
+# with_df(df[1, ][[3]] <- list(NULL))
+# with_tbl(tbl[1, ][[3]] <- list(NULL))
+# with_df2(df2[[1, 1]] <- df[1, ])
+# with_tbl2(tbl2[[1, 1]] <- tbl[1, ])
+# with_df2(df2[1, ][[1]] <- df[1, ])
+# with_tbl2(tbl2[1, ][[1]] <- tbl[1, ])
+# with_df2(df2[[1, 2]] <- t(1:4))
+# with_tbl2(tbl2[[1, 2]] <- t(1:4))
+# with_df2(df2[1, ][[2]] <- t(1:4))
+# with_tbl2(tbl2[1, ][[2]] <- t(1:4))
+# df[[1:2, 1]]
+# tbl[[1:2, 1]]
+# with_df(df[[1:2, 1]] <- 0)
+# with_tbl(tbl[[1:2, 1]] <- 0)
 
 ## ----check, dftbl = TRUE, include = FALSE-------------------------------------
 
